module.exports = defineTest({
	description: '`delete` operator at the top level is preserved'
});
